//
//  ViewController.swift
//  StripeCustomDemo
//
//  Created by MacOs14 on 24/12/19.
//  Copyright © 2019 MacOs14. All rights reserved.
//

import UIKit
import Stripe

class ViewController: UIViewController {
    
//    var stripePublishableKey = "pk_test_0uVMBC6Im7TKjCuA47DP4dhn00ulPQWzXv"
//
//    var backendBaseURL: String? = "http://192.168.0.126:8000/api/v1/"
//
//    var appleMerchantID: String? = ""
    
    // These values will be shown to the user when they purchase with Apple Pay.
    let companyName = "Emoji Apparel"
    let paymentCurrency: String = "usd"
    
    var paymentContext: STPPaymentContext!
    
    var stripeKey : String
    var backendBaseURL : String
    var appleMerchantID : String
    var ephemeralKey : [AnyHashable : Any]
    var orderId : String
    var authToken: String
    var onClose : (() -> ())!
    var onSuccess : ((_ stripeId: String) -> ())!
    var onError : ((_ errorMessage: String) -> ())!
    var onCancel : (() -> ())!
        
    var striperToken = ""

    
    init(with stripeKey : String, backendBaseURL: String, appleMerchantID: String, ephemeralKey : [AnyHashable : Any], orderId: String, authToken: String) {
        self.stripeKey = stripeKey
        self.backendBaseURL = backendBaseURL
        self.appleMerchantID = appleMerchantID
        self.ephemeralKey = ephemeralKey
        self.orderId = orderId
        self.authToken = authToken
        
        super.init(nibName: nil, bundle: nil)
    }
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    var btnPaymentType: UIButton!
    var btnPayNow: UIButton!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        initTesttt()
        
        self.view.backgroundColor = UIColor.init(red: 98/255.0, green: 98/255.0, blue: 98/255.0, alpha: 1.0)
        
        let label = UILabel(frame: CGRect(origin: CGPoint(x: 0, y: 30), size: CGSize(width: self.view.frame.width, height: 30)))
        label.text = "Select Payment Method"
        label.textAlignment = .center
        self.view.addSubview(label)
                
         btnPaymentType = UIButton(frame:  CGRect(origin: CGPoint(x: 0, y: label.frame.maxY + 20), size: CGSize(width: 200, height: 36)))
        btnPaymentType.center = CGPoint(x: self.view.center.x, y: label.frame.maxY + 20)
        btnPaymentType.backgroundColor = UIColor.init(red: 40/255.0, green: 0.0, blue: 0.0, alpha: 1.0)
        btnPaymentType.setTitle("Select Payment", for: .normal)
        btnPaymentType.setTitleColor(UIColor.white, for: .normal)
        btnPaymentType.setTitleColor(UIColor.gray, for: .disabled)
        btnPaymentType.addTarget(self, action: #selector(onPaymentChoose), for: .touchUpInside)
        btnPaymentType.layer.cornerRadius = 18
        btnPaymentType.clipsToBounds = true
        
        self.view.addSubview(btnPaymentType)
        
        btnPayNow = UIButton(frame:  CGRect(origin: CGPoint(x: 0, y: self.view.frame.maxY - 100), size: CGSize(width: 150, height: 36)))
        btnPayNow.center = CGPoint(x: self.view.center.x, y: self.view.frame.maxY - 100)
        btnPayNow.setTitle("Pay Now", for: .normal)
        btnPayNow.setTitleColor(UIColor.white, for: .normal)
        btnPayNow.setTitleColor(UIColor.gray, for: .disabled)
        btnPayNow.layer.cornerRadius = 18
        btnPayNow.clipsToBounds = true
        btnPayNow.backgroundColor = UIColor.init(red: 40/255.0, green: 0.0, blue: 0.0, alpha: 1.0)
        btnPayNow.addTarget(self, action: #selector(onPaymentBuy), for: .touchUpInside)
        btnPayNow.isEnabled = false
        self.view.addSubview(btnPayNow)
    }
    
    func initTesttt() {
                
        assert(stripeKey.hasPrefix("pk_"), "You must set your Stripe publishable key at the top of CheckoutViewController.swift to run this app.")
        
        MyAPIClient.sharedClient.baseURLString = backendBaseURL
        MyAPIClient.sharedClient.ephemeralKey = ephemeralKey
        
        // This code is included here for the sake of readability, but in your application you should set up your configuration and theme earlier, preferably in your App Delegate.
        let config = STPPaymentConfiguration.shared()
        config.publishableKey = stripeKey
        config.appleMerchantIdentifier = appleMerchantID
        config.companyName = self.companyName
        config.requiredBillingAddressFields = STPBillingAddressFields.name
        
        let customerContext = STPCustomerContext(keyProvider: MyAPIClient.sharedClient)
        let paymentContext = STPPaymentContext(customerContext: customerContext,
                                               configuration: config,
                                               theme: STPTheme())
        let userInformation = STPUserInformation()
        paymentContext.prefilledInformation = userInformation
        paymentContext.paymentAmount = 100
        paymentContext.paymentCurrency = self.paymentCurrency
                
        self.paymentContext = paymentContext
        
        let numberFormatter = NumberFormatter()
        //        numberFormatter.locale = settings.currencyLocale
        numberFormatter.numberStyle = .currency
        numberFormatter.usesGroupingSeparator = true
        //        self.numberFormatter = numberFormatter
        
        self.paymentContext.delegate = self
        paymentContext.hostViewController = self
    }
    
    func tapPushPayment() {
        self.paymentContext.presentPaymentOptionsViewController()
    }
    
    @objc func didTapBuy() {
        self.paymentContext.requestPayment()
    }
}

// MARK: STPPaymentContextDelegate
extension ViewController: STPPaymentContextDelegate {
    enum CheckoutError: Error {
        case unknown
        
        var localizedDescription: String {
            switch self {
            case .unknown:
                return "Unknown error"
            }
        }
    }
    
    
    func paymentContext(_ paymentContext: STPPaymentContext, didCreatePaymentResult paymentResult: STPPaymentResult, completion: @escaping STPPaymentStatusBlock) {
        // Request a PaymentIntent from your backend
        MyAPIClient.sharedClient.createPaymentIntent(order_id: self.orderId,authToken : self.authToken) { result in
            switch result {
            case .success(let clientSecret):
                // Assemble the PaymentIntent parameters
                let paymentIntentParams = STPPaymentIntentParams(clientSecret: clientSecret)
                paymentIntentParams.paymentMethodId = paymentResult.paymentMethod?.stripeId
                paymentIntentParams.configure(with: paymentResult)
//                paymentIntentParams.paymentMethodParams = paymentResult.paymentMethodParams
                paymentIntentParams.returnURL = "stripedemo://stripe-redirect"
                
                // Confirm the PaymentIntent
                STPPaymentHandler.shared().confirmPayment(withParams: paymentIntentParams, authenticationContext: self.paymentContext) { status, paymentIntent, error in
                    switch status {
                    case .succeeded:
                        // Your backend asynchronously fulfills the customer's order, e.g. via webhook
                        self.striperToken = paymentIntentParams.stripeId ?? ""
                        completion(.success, nil)
                    case .failed:
                        completion(.error, error) // Report error
                    case .canceled:
                        completion(.userCancellation, nil) // Customer cancelled
                    @unknown default:
                        completion(.error, nil)
                    }
                }
            case .failure(let error):
                completion(.error, error) // Report error from your API
                break
            }
        }
    }
    
    func paymentContext(_ paymentContext: STPPaymentContext, didFinishWith status: STPPaymentStatus, error: Error?) {
        
        switch status {
        case .error:
            self.onError(error?.localizedDescription ?? "")
        case .success:
            self.onSuccess(striperToken)
        case .userCancellation:
            self.onCancel()
        @unknown default:
            self.onClose()
            break
        }
        
        self.dismiss(animated: true, completion: nil)
        
    }
    
    @objc func onPaymentChoose() {
        self.tapPushPayment()
    }
    
    @objc func onPaymentBuy() {
        self.didTapBuy()
    }
    
    func paymentContextDidChange(_ paymentContext: STPPaymentContext) {
        
        print(paymentContext.loading)
        
        if let paymentOption = paymentContext.selectedPaymentOption {
            print(paymentOption.label)
            btnPaymentType.setTitle(paymentOption.label, for: .normal)
            btnPayNow.isEnabled = true
            btnPaymentType.isEnabled = true
        } else {
            btnPaymentType.setTitle("Select Payment", for: .normal)
            btnPaymentType.isEnabled = false
            btnPayNow.isEnabled = false
            print("Select Payment")
        }
    }
    
    func paymentContext(_ paymentContext: STPPaymentContext, didFailToLoadWithError error: Error) {
        let alertController = UIAlertController(
            title: "Error",
            message: error.localizedDescription,
            preferredStyle: .alert
        )
        let cancel = UIAlertAction(title: "Cancel", style: .cancel, handler: { action in
            // Need to assign to _ because optional binding loses @discardableResult value
            // https://bugs.swift.org/browse/SR-1681
            self.onClose()
            self.dismiss(animated: true, completion: nil)
        })
        let retry = UIAlertAction(title: "Retry", style: .default, handler: { action in
            self.paymentContext.retryLoading()
        })
        alertController.addAction(cancel)
        alertController.addAction(retry)
        self.present(alertController, animated: true, completion: nil)
    }
    
    // Note: this delegate method is optional. If you do not need to collect a
    // shipping method from your user, you should not implement this method.
    func paymentContext(_ paymentContext: STPPaymentContext, didUpdateShippingAddress address: STPAddress, completion: @escaping STPShippingMethodsCompletionBlock) {
        
    }
}



