import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class StripePlugin {
  static const MethodChannel _channel = const MethodChannel('stripe_plugin');

  static Future<String> openBasicPayment(StripeReq req) async {
    var result = await _channel.invokeMethod(
      'openBasicIntent',
      req.toJson(),
    );

    if (result is String) {
      return result;
    } else if (result is FlutterError) {
      throw result;
    }
    return null;
  }
}

class StripeReq {
  String stripeKey;
  String backendBaseURL;
  String appleMerchantID;
  Map<String, dynamic> ephemeralKey;
  String orderId;
  String authToken;

  StripeReq({
    this.stripeKey,
    this.backendBaseURL,
    this.appleMerchantID,
    this.ephemeralKey,
    this.orderId,
    this.authToken,
  });

  StripeReq.fromJson(Map<String, dynamic> json) {
    stripeKey = json['stripeKey'];
    backendBaseURL = json['backendBaseURL'];
    appleMerchantID = json['appleMerchantID'];
    ephemeralKey = json['ephemeralKey'];
    orderId = json['orderId'];
    authToken = json['authToken'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['stripeKey'] = this.stripeKey;
    data['backendBaseURL'] = this.backendBaseURL;
    data['appleMerchantID'] = this.appleMerchantID;
    data['ephemeralKey'] = this.ephemeralKey;
    data['orderId'] = this.orderId;
    data['authToken'] = this.authToken;
    return data;
  }
}
